==> OpenPatricianModel-0.4.1-sources.jar: ch/sahits/game/openpatrician/spring/ModelConfiguration.java <==
package ch.sahits.game.openpatrician.spring;

import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.city.impl.City;
import ch.sahits.game.openpatrician.model.time.EUpdateIntervalRegistration;
import ch.sahits.game.openpatrician.model.time.PeriodicalTimeUpdaterV2;
import ch.sahits.game.openpatrician.util.RandomNameLoader;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.PropertiesFactoryBean;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;
import org.springframework.context.annotation.Scope;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.core.env.Environment;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

import java.util.Locale;
import java.util.Random;

/**
 * Java configuration of the spring context.
 * @author Andi Hotz, (c) Sahits GmbH, 2014
 *         Created on Feb 02, 2014
 */
@Configuration
@ComponentScan(basePackages = {"ch.sahits.game.openpatrician.model", "ch.sahits.game.openpatrician.util"})
public class ModelConfiguration {

    //    @Value("${user.home}")
//    private String userHome;
    @Autowired
    private Environment standardEnvironment;

    @Bean
    public Random rnd() {
        return new Random();
    }

    @Bean
    public Jaxb2Marshaller jaxb2MapMarshaller() {
        Jaxb2Marshaller bean = new Jaxb2Marshaller();
        bean.setContextPath("ch.sahits.game.openpatrician.data.map");
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer applicationProperties(@Value("#{systemProperties['user.home']}") String userHome) {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("model-settings.properties"),
                new FileSystemResource(userHome + "/.OpenPatrician/OpenPatricianConfiguration.properties")});
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer difficulty() {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("difficulty_level_easy.properties")});
        return bean;
    }

    @Bean
    public PropertiesFactoryBean model() {
        PropertiesFactoryBean bean = new PropertiesFactoryBean();
        bean.setLocation(new ClassPathResource("populationConsume_default.properties"));
        return bean;
    }

    @Bean
    public Locale defaultLocale() {
        return Locale.ENGLISH;
    }

    @Bean
    public RandomNameLoader firstNameLoader() {
        return new RandomNameLoader("firstnames.properties");
    }

    @Bean
    public RandomNameLoader lastNameLoader() {
        return new RandomNameLoader("lastnames.properties");
    }

    @Bean
    public RandomNameLoader shipNameLoader() {
        return new RandomNameLoader("shipnames.properties");
    }

    @Bean
    public PropertiesFactoryBean modelProperties() {
        PropertiesFactoryBean propertyFact = new PropertiesFactoryBean();
        propertyFact.setLocation(new ClassPathResource("model.properties"));
        return propertyFact;
    }

    @Bean
    @Scope("prototype")
    public ICity cityBean(ch.sahits.game.openpatrician.data.map.City cityData) {
        return new City(cityData);
    }

    @Bean
    public ReloadableResourceBundleMessageSource messageSource() {
        ReloadableResourceBundleMessageSource bundle = new ReloadableResourceBundleMessageSource();
        bundle.setDefaultEncoding("UTF-8");
        bundle.setBasename("/text");
        return bundle;
    }

    /**
     * Create a new periodical updater. Periodical updates are not intended to be unregistered.
     *
     * @param intervall
     * @return
     */
    @Bean
    @Scope("prototype")
    // TODO they are singletons per intervall
    public PeriodicalTimeUpdaterV2 periodicalUpdater(EUpdateIntervalRegistration intervall) {
        return new PeriodicalTimeUpdaterV2(intervall);
    }

    /**
     * Create a periodical updater for end of day which is a singleton.
     *
     * @return
     */
    @Bean
    @Lazy
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalEndOfDayUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.END_OF_DAY);
    }

    /**
     * Create a periodical updater for weekly updates which is a singleton.
     * @return
     */
    @Bean
    @Lazy
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalWeeklyUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.WEEK);
    }
}

==> OpenPatricianModel-0.5.0-sources.jar: ch/sahits/game/openpatrician/spring/ModelConfiguration.java <==
package ch.sahits.game.openpatrician.spring;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.DependentInitialisation;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.city.impl.City;
import ch.sahits.game.openpatrician.model.time.EUpdateIntervalRegistration;
import ch.sahits.game.openpatrician.model.time.PeriodicalTimeUpdaterV2;
import ch.sahits.game.openpatrician.util.RandomNameLoader;
import ch.sahits.game.openpatrician.util.StartNewGameBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.PropertiesFactoryBean;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;
import org.springframework.context.annotation.Scope;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.core.env.Environment;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

import java.util.Locale;
import java.util.Random;

/**
 * Java configuration of the spring context.
 * @author Andi Hotz, (c) Sahits GmbH, 2014
 *         Created on Feb 02, 2014
 */
@Configuration
@ComponentScan(basePackages = {"ch.sahits.game.openpatrician.model", "ch.sahits.game.openpatrician.util", "ch.sahits.game.openpatrician.persistence.converter"})
@ClassCategory(EClassCategory.STARTUP)
public class ModelConfiguration {

    //    @Value("${user.home}")
//    private String userHome;
    @Autowired
    private Environment standardEnvironment;

    @Bean
    public Random rnd() {
        return new Random();
    }

    @Bean
    public Jaxb2Marshaller jaxb2MapMarshaller() {
        Jaxb2Marshaller bean = new Jaxb2Marshaller();
        bean.setContextPath("ch.sahits.game.openpatrician.data.map");
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer applicationProperties(@Value("#{systemProperties['user.home']}") String userHome) {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("model-settings.properties"),
                new FileSystemResource(userHome + "/.OpenPatrician/OpenPatricianConfiguration.properties")});
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer difficulty() {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("difficulty_level_easy.properties")});
        return bean;
    }

    @Bean
    public PropertiesFactoryBean model() {
        PropertiesFactoryBean bean = new PropertiesFactoryBean();
        bean.setLocation(new ClassPathResource("populationConsume_default.properties"));
        return bean;
    }

    @Bean
    public Locale defaultLocale() {
        return Locale.ENGLISH;
    }

    @Bean
    public RandomNameLoader firstNameLoader() {
        return new RandomNameLoader("firstnames.properties");
    }

    @Bean
    public RandomNameLoader lastNameLoader() {
        return new RandomNameLoader("lastnames.properties");
    }

    @Bean
    public RandomNameLoader shipNameLoader() {
        return new RandomNameLoader("shipnames.properties");
    }

    @Bean
    public PropertiesFactoryBean modelProperties() {
        PropertiesFactoryBean propertyFact = new PropertiesFactoryBean();
        propertyFact.setLocation(new ClassPathResource("model.properties"));
        return propertyFact;
    }

    @Bean
    @Scope("prototype")
    public ICity cityBean(ch.sahits.game.openpatrician.data.map.City cityData) {
        return new City(cityData);
    }

    @Bean
    public ReloadableResourceBundleMessageSource messageSource() {
        ReloadableResourceBundleMessageSource bundle = new ReloadableResourceBundleMessageSource();
        bundle.setDefaultEncoding("UTF-8");
        bundle.setBasename("i18n/text");
        return bundle;
    }


    /**
     * Create a periodical updater for end of day which is a singleton.
     *
     * @return
     */
    @Bean
    @Lazy
    @DependentInitialisation(value = StartNewGameBean.class, registerWithBeanName = true)
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalEndOfDayUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.END_OF_DAY);
    }

    /**
     * Create a periodical updater for end of week which is a singleton.
     *
     * @return
     */
    @Bean
    @Lazy
    @DependentInitialisation(value = StartNewGameBean.class, registerWithBeanName = true)
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalEndOfWeekUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.END_OF_WEEK);
    }

    /**
     * Create a periodical updater for end of month which is a singleton.
     *
     * @return
     */
    @Bean
    @Lazy
    @DependentInitialisation(value = StartNewGameBean.class, registerWithBeanName = true)
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalEndOfMonthUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.END_OF_MONTH);
    }
    /**
     * Create a periodical updater for end of year which is a singleton.
     *
     * @return
     */
    @Bean
    @Lazy
    @DependentInitialisation(value = StartNewGameBean.class, registerWithBeanName = true)
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalEndOfYearUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.END_OF_YEAR);
    }
    /**
     * Create a periodical updater for weekly updates which is a singleton.
     * @return
     */
    @Bean
    @Lazy
    @DependentInitialisation(value = StartNewGameBean.class, registerWithBeanName = true)
    // todo: andi 12/30/14: They do not have to be injected anywhere as the notification happens through the eventbus, but they have to instantiated after the start year is set
    public PeriodicalTimeUpdaterV2 periodicalWeeklyUpdater() {
        return new PeriodicalTimeUpdaterV2(EUpdateIntervalRegistration.WEEK);
    }
}
